searchData={"items":[{"type":"module","title":"Truly","doc":"Create a truth table to consolidate complex boolean conditional logic.\n\n`Truly` provides a convenient and human-readable way to store complex conditional logic trees.\nYou can immediately use `Truly.evaluate/2` to evaluate the truth table or pass the truth table\naround for repeat use.\n\nYou might find this useful for things like feature flags, where depending on the combination\nof boolean flags you want different behaviors or paths.\n\nThis can also make the design much more self-documented, where the intent behind a large\nlogic ladder becomes quite clear.","ref":"Truly.html"},{"type":"module","title":"Installation - Truly","doc":"The package can be installed\nby adding `truly` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:truly, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"Truly.html#module-installation"},{"type":"module","title":"Usage - Truly","doc":"First, you must `import Truly`. Then you have the\n`~TRULY` sigil available.\n\nAll column names and result values must be valid (and existing) atoms.\n\nTable cells can only be boolean values.\n\nYou must provide an exhaustive truth table, meaning that you provide\neach combination of column values.","ref":"Truly.html#module-usage"},{"type":"module","title":"Example - Truly","doc":"```elixir\nimport Truly\ncolumns = [:flag_a, :flag_b, :flag_c]\ncategories = [:cat1, :cat2, :cat3]\n\n{:ok, tt} = ~TRULY\"\"\"\n| flag_a |  flag_b | flag_c   |          |  \n|--------|---------|----------|----------|\n|   0    |    0    |     0    |   cat1   |\n|   0    |    0    |     1    |   cat1   |\n|   0    |    1    |     0    |   cat2   |\n|   0    |    1    |     1    |   cat1   |\n|   1    |    0    |     0    |   cat3   |\n|   1    |    0    |     1    |   cat1   |\n|   1    |    1    |     0    |   cat2   |\n|   1    |    1    |     1    |   cat3   |\n\"\"\"\n\nTruly.evaluate!(tt,[flag_a: 1, flag_b: 1, flag_c: 1])\n\nflag_a = 0\nflag_b = 1\nflag_c = 0\n\nTruthTable.evaluate(tt,binding())\n```","ref":"Truly.html#module-example"},{"type":"function","title":"Truly.evaluate/2","doc":"","ref":"Truly.html#evaluate/2"},{"type":"function","title":"Truly.evaluate!/2","doc":"","ref":"Truly.html#evaluate!/2"},{"type":"function","title":"Truly.sigil_TRULY/2","doc":"","ref":"Truly.html#sigil_TRULY/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}